@@ -3,11 +3,14 @@
 
 namespace Icinga\Cli\Documentation;
 
+use Icinga\Cli\Screen;
+
 class CommentParser
 {
     protected $raw;
     protected $plain;
     protected $title;
+    /** @var array $paragraphs */
     protected $paragraphs = array();
 
     public function __construct($raw)
@@ -35,6 +38,7 @@ class CommentParser
         $p = null;
         foreach (preg_split('~\n~', $plain) as $line) {
             // Strip * at line start
+            /** @var string $line */
             $line = preg_replace('~^\s*\*\s?~', '', $line);
             $line = rtrim($line);
             if ($this->title === null) {
@@ -68,10 +72,16 @@ class CommentParser
 
     public function dump()
     {
-        $res = $this->title . "\n" . str_repeat('=', strlen($this->title)) . "\n\n";
-        foreach ($this->paragraphs as $p) {
-            $res .= wordwrap($p, 72) . "\n\n";
+        if ($this->title) {
+            $res = $this->title . "\n" . str_repeat('=', strlen($this->title)) . "\n\n";
+        } else {
+            $res = '';
         }
+
+        foreach ($this->paragraphs as $p) {
+            $res .= wordwrap($p, Screen::instance()->getColumns()) . "\n\n";
+        }
+
         return $res;
     }
 }
