@@ -62,19 +62,6 @@ class DashboardPane extends NavigationItem
         $this->setUrl(Url::fromPath('dashboard', array('pane' => $this->getName())));
     }
 
-    /**
-     * {@inheritdoc}
-     */
-    public function merge(NavigationItem $item)
-    {
-        parent::merge($item);
-
-        $this->setDashlets(array_merge(
-            $this->getDashlets(false),
-            $item->getDashlets(false)
-        ));
-    }
-
     /**
      * Set disabled state for pane
      *
