@@ -1,6 +1,8 @@
 <?php
 /* Icinga Web 2 | (c) 2014 Icinga Development Team | GPLv2+ */
 
+use Icinga\Authentication\Auth;
+
 /** @var $this \Icinga\Application\Modules\Module */
 
 $this->providePermission(
@@ -11,6 +13,10 @@ $this->providePermission(
     'monitoring/command/schedule-check',
     $this->translate('Allow scheduling host and service checks')
 );
+$this->providePermission(
+    'monitoring/command/schedule-check/active-only',
+    $this->translate('Allow scheduling host and service checks (Only on objects with active checks enabled)')
+);
 $this->providePermission(
     'monitoring/command/acknowledge-problem',
     $this->translate('Allow acknowledging host and service problems')
@@ -79,6 +85,10 @@ $this->providePermission(
     'monitoring/command/send-custom-notification',
     $this->translate('Allow sending custom notifications for hosts and services')
 );
+$this->providePermission(
+    'no-monitoring/contacts',
+    $this->translate('Prohibit access to contacts and contactgroups')
+);
 
 $this->provideRestriction(
     'monitoring/filter/objects',
@@ -104,6 +114,7 @@ $this->provideSetupWizard('Icinga\Module\Monitoring\MonitoringWizard');
 /*
  * Available Search Urls
  */
+$this->provideSearchUrl($this->translate('Tactical Overview'), 'monitoring/tactical', 100);
 $this->provideSearchUrl($this->translate('Hosts'), 'monitoring/list/hosts?sort=host_severity&limit=10', 99);
 $this->provideSearchUrl($this->translate('Services'), 'monitoring/list/services?sort=service_severity&limit=10', 98);
 $this->provideSearchUrl($this->translate('Hostgroups'), 'monitoring/list/hostgroups?limit=10', 97);
@@ -207,18 +218,24 @@ $section->add(N_('Hostgroups'), array(
     'url'         => 'monitoring/list/hostgroups',
     'priority'    => 60
 ));
-$section->add(N_('Contacts'), array(
-    'icon'        => 'user',
-    'description' => $this->translate('List contacts'),
-    'url'         => 'monitoring/list/contacts',
-    'priority'    => 70
-));
-$section->add(N_('Contactgroups'), array(
-    'icon'        => 'users',
-    'description' => $this->translate('List users'),
-    'url'         => 'monitoring/list/contactgroups',
-    'priority'    => 70
-));
+
+// Checking the permission here since navigation items don't support negating permissions
+$auth = Auth::getInstance();
+if ($auth->hasPermission('*') || ! $auth->hasPermission('no-monitoring/contacts')) {
+    $section->add(N_('Contacts'), array(
+        'icon'        => 'user',
+        'description' => $this->translate('List contacts'),
+        'url'         => 'monitoring/list/contacts',
+        'priority'    => 70
+    ));
+    $section->add(N_('Contactgroups'), array(
+        'icon'        => 'users',
+        'description' => $this->translate('List users'),
+        'url'         => 'monitoring/list/contactgroups',
+        'priority'    => 70
+    ));
+}
+
 $section->add(N_('Comments'), array(
     'icon'        => 'chat-empty',
     'description' => $this->translate('List comments'),
@@ -272,33 +289,24 @@ $section = $this->menuSection(N_('Reporting'), array(
     'priority'  => 100
 ));
 
-/*
- * System Section
- */
-$section = $this->menuSection(N_('System'));
-$section->add(N_('Monitoring Health'), array(
-    'icon'        => 'check',
-    'description' => $this->translate('Open monitoring health'),
-    'url'         => 'monitoring/health/info',
-    'priority'    => 720,
-    'renderer'    => 'BackendAvailabilityNavigationItemRenderer'
-));
-
 /*
  * Current Incidents
  */
 $dashboard = $this->dashboard(N_('Current Incidents'), array('priority' => 50));
 $dashboard->add(
     N_('Service Problems'),
-    'monitoring/list/services?service_problem=1&limit=10&sort=service_severity'
+    'monitoring/list/services?service_problem=1&limit=10&sort=service_severity',
+    100
 );
 $dashboard->add(
     N_('Recently Recovered Services'),
-    'monitoring/list/services?service_state=0&limit=10&sort=service_last_state_change&dir=desc'
+    'monitoring/list/services?service_state=0&limit=10&sort=service_last_state_change&dir=desc',
+    110
 );
 $dashboard->add(
     N_('Host Problems'),
-    'monitoring/list/hosts?host_problem=1&sort=host_severity'
+    'monitoring/list/hosts?host_problem=1&sort=host_severity',
+    120
 );
 
 /*
@@ -324,19 +332,23 @@ $dashboard->add(
 $dashboard = $this->dashboard(N_('Overdue'), array('priority' => 70));
 $dashboard->add(
     N_('Late Host Check Results'),
-    'monitoring/list/hosts?host_next_update<now'
+    'monitoring/list/hosts?host_next_update<now',
+    100
 );
 $dashboard->add(
     N_('Late Service Check Results'),
-    'monitoring/list/services?service_next_update<now'
+    'monitoring/list/services?service_next_update<now',
+    110
 );
 $dashboard->add(
     N_('Acknowledgements Active For At Least Three Days'),
-    'monitoring/list/comments?comment_type=Ack&comment_timestamp<-3 days&sort=comment_timestamp&dir=asc'
+    'monitoring/list/comments?comment_type=Ack&comment_timestamp<-3 days&sort=comment_timestamp&dir=asc',
+    120
 );
 $dashboard->add(
     N_('Downtimes Active For More Than Three Days'),
-    'monitoring/list/downtimes?downtime_is_in_effect=1&downtime_scheduled_start<-3%20days&sort=downtime_start&dir=asc'
+    'monitoring/list/downtimes?downtime_is_in_effect=1&downtime_scheduled_start<-3%20days&sort=downtime_start&dir=asc',
+    130
 );
 
 /*
@@ -345,27 +357,33 @@ $dashboard->add(
 $dashboard = $this->dashboard(N_('Muted'), array('priority' => 80));
 $dashboard->add(
     N_('Disabled Service Notifications'),
-    'monitoring/list/services?service_notifications_enabled=0&limit=10'
+    'monitoring/list/services?service_notifications_enabled=0&limit=10',
+    100
 );
 $dashboard->add(
     N_('Disabled Host Notifications'),
-    'monitoring/list/hosts?host_notifications_enabled=0&limit=10'
+    'monitoring/list/hosts?host_notifications_enabled=0&limit=10',
+    110
 );
 $dashboard->add(
     N_('Disabled Service Checks'),
-    'monitoring/list/services?service_active_checks_enabled=0&limit=10'
+    'monitoring/list/services?service_active_checks_enabled=0&limit=10',
+    120
 );
 $dashboard->add(
     N_('Disabled Host Checks'),
-    'monitoring/list/hosts?host_active_checks_enabled=0&limit=10'
+    'monitoring/list/hosts?host_active_checks_enabled=0&limit=10',
+    130
 );
 $dashboard->add(
     N_('Acknowledged Problem Services'),
-    'monitoring/list/services?service_acknowledgement_type=2&service_problem=1&sort=service_state&limit=10'
+    'monitoring/list/services?service_acknowledgement_type!=0&service_problem=1&sort=service_state&limit=10',
+    140
 );
 $dashboard->add(
     N_('Acknowledged Problem Hosts'),
-    'monitoring/list/hosts?host_acknowledgement_type=2&host_problem=1&sort=host_severity&limit=10'
+    'monitoring/list/hosts?host_acknowledgement_type!=0&host_problem=1&sort=host_severity&limit=10',
+    150
 );
 
 /*
@@ -409,5 +427,6 @@ $dashboard->add(
 /*
  * CSS
  */
+$this->provideCssFile('event-grid.less');
 $this->provideCssFile('service-grid.less');
 $this->provideCssFile('tables.less');
