@@ -29,7 +29,9 @@ class HostdowntimeendhistoryQuery extends HostdowntimestarthistoryQuery
     protected function joinBaseTables()
     {
         parent::joinBaseTables(true);
-        $this->select->where("hdh.actual_end_time > '1970-01-02 00:00:00'");
+        $this->select->where(
+            "hdh.actual_end_time > '1970-01-02 00:00:00' AND hdh.was_started = 1"
+        );
         $this->columnMap['downtimehistory']['type'] = "('dt_end')";
         $this->columnMap['downtimehistory']['timestamp'] = str_replace(
             'actual_start_time',
